"use strict";
// *****************************************************************************
// Copyright (C) 2019 TypeFox and others.
//
// This program and the accompanying materials are made available under the
// terms of the Eclipse Public License v. 2.0 which is available at
// http://www.eclipse.org/legal/epl-2.0.
//
// This Source Code may also be made available under the following Secondary
// Licenses when the conditions for such availability set forth in the Eclipse
// Public License v. 2.0 are satisfied: GNU General Public License, version 2
// with the GNU Classpath Exception which is available at
// https://www.gnu.org/software/classpath/license.html.
//
// SPDX-License-Identifier: EPL-2.0 OR GPL-2.0-only WITH Classpath-exception-2.0
// *****************************************************************************
Object.defineProperty(exports, "__esModule", { value: true });
exports.messagingFrontendModule = void 0;
const inversify_1 = require("inversify");
const frontend_application_contribution_1 = require("../../browser/frontend-application-contribution");
const ws_connection_provider_1 = require("../../browser/messaging/ws-connection-provider");
const electron_ws_connection_provider_1 = require("./electron-ws-connection-provider");
const electron_ipc_connection_provider_1 = require("./electron-ipc-connection-provider");
const electron_local_ws_connection_provider_1 = require("./electron-local-ws-connection-provider");
exports.messagingFrontendModule = new inversify_1.ContainerModule(bind => {
    bind(electron_ws_connection_provider_1.ElectronWebSocketConnectionProvider).toSelf().inSingletonScope();
    bind(frontend_application_contribution_1.FrontendApplicationContribution).toService(electron_ws_connection_provider_1.ElectronWebSocketConnectionProvider);
    bind(ws_connection_provider_1.WebSocketConnectionProvider).toService(electron_ws_connection_provider_1.ElectronWebSocketConnectionProvider);
    bind(electron_local_ws_connection_provider_1.ElectronLocalWebSocketConnectionProvider).toSelf().inSingletonScope();
    bind(ws_connection_provider_1.LocalWebSocketConnectionProvider).toDynamicValue(ctx => {
        const localPort = (0, electron_local_ws_connection_provider_1.getLocalPort)();
        if (localPort) {
            // Return new web socket provider that connects to local app
            return ctx.container.get(electron_local_ws_connection_provider_1.ElectronLocalWebSocketConnectionProvider);
        }
        else {
            // Return the usual web socket provider that already established its connection
            // That way we don't create a second socket connection
            return ctx.container.get(ws_connection_provider_1.WebSocketConnectionProvider);
        }
    }).inSingletonScope();
    bind(electron_ipc_connection_provider_1.ElectronIpcConnectionProvider).toSelf().inSingletonScope();
});
//# sourceMappingURL=electron-messaging-frontend-module.js.map